use std::path::PathBuf;

#[derive(Clone, Debug)]
pub struct CommitArtifact {
    pub app: String,
    pub branch: String,
    pub folder: PathBuf,
}

#[derive(Debug, Clone)]
pub struct ArtifactID(uuid::Uuid);

impl ArtifactID {
    pub fn new() -> Self {
        Self(uuid::Uuid::now_v7())
    }
}

impl std::ops::Deref for ArtifactID {
    type Target = uuid::Uuid;

    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl TryFrom<String> for ArtifactID {
    type Error = anyhow::Error;

    fn try_from(value: String) -> Result<Self, Self::Error> {
        let uuid = uuid::Uuid::parse_str(&value)?;

        Ok(ArtifactID(uuid))
    }
}
